@@ -48,3 +48,16 @@ test_that("logs UI works", {
 })
 
 
+test_that("fab_button works", {
+  
+  fab_button_tags <- fab_button()
+  
+  expect_is(fab_button_tags, "shiny.tag.list")
+})
+
+test_that("secure_app works", {
+  
+  sa <- secure_app(fluidPage())
+  
+  expect_is(sa, "function")
+})
